A fixed or non-mm-managed mapping is one which sets VMA_PFNMAP_BIT,
VMA_MIXEDMAP_BIT or VMA_DONTEXPAND_BIT, which is precisely what
VMA_SPECIAL_FLAGS tests for other than VMA_IO_BIT, which is safe to drop as
mm-managed mappings may not set it.

Using these predicates rather than VMA_SPECIAL_FLAGS makes the check
self-documenting and helps eliminate the confusion around 'special' flags.

No functional change intended.

Reviewed-by: Zi Yan <[email protected]>
Acked-by: David Hildenbrand (Arm) <[email protected]>
Signed-off-by: Lorenzo Stoakes (ARM) <[email protected]>
---
 mm/vmscan.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/mm/vmscan.c b/mm/vmscan.c
index 3b318efa2916..7adffe8182b3 100644
--- a/mm/vmscan.c
+++ b/mm/vmscan.c
@@ -4418,8 +4418,8 @@ bool lru_gen_look_around(struct page_vma_mapped_walk 
*pvmw, unsigned int nr)
        if (spin_is_contended(pvmw->ptl))
                return true;
 
-       /* exclude special VMAs containing anon pages from COW */
-       if (vma->vm_flags & VM_SPECIAL)
+       /* exclude fixed and non-mm-managed VMAs containing anon pages from COW 
*/
+       if (!vma_is_mm_managed(vma) || vma_is_fixed_mapping(vma))
                return true;
 
        /* avoid taking the LRU lock under the PTL when possible */

-- 
2.55.0


Reply via email to